@@ -4,7 +4,7 @@ use Carp;
 
 sub parse {
     my($class, $string, $url) = @_;
-    my @res = split /;\s*/, $string;
+    my @res = split /\s*;\s*/, $string;
     map $class->_parse($_, $url), @res;
 }
 
@@ -19,26 +19,22 @@ sub _parse {
 
     if ($self->{type} ne 'DIRECT') {
         my $proxy = URI->new;
-        $proxy->scheme($url->scheme); # same scheme as the target host
+        $proxy->scheme('http');
         $proxy->host_port($string);
 
         $self->{lc($self->{type})} = $proxy;
     }
-
     bless $self, $class;
 }
-
 sub direct { $_[0]->{type} eq 'DIRECT' }
 sub proxy  { $_[0]->{proxy} }
 sub socks  { $_[0]->{socks} }
-
 1;
-
 __END__
 
 =head1 NAME
 
-HTTP::ProxyPAC::Result - Result object for HTTP::ProxyPAC find_proxy
+HTTP::ProxyPAC::Result - Result object from HTTP::ProxyPAC find_proxy
 
 =head1 SYNOPSIS
 
@@ -51,7 +47,8 @@ HTTP::ProxyPAC::Result - Result object for HTTP::ProxyPAC find_proxy
 
 =head1 DESCRIPTION
 
-HTTP::ProxyPAC::Result is a class to encapsulate result object from find_proxy method.
+HTTP::ProxyPAC::Result is the class of the result object from the 
+find_proxy method of HTTP::ProxyPAC.
 
 =head1 METHODS
 
@@ -59,15 +56,15 @@ HTTP::ProxyPAC::Result is a class to encapsulate result object from find_proxy m
 
 =item direct
 
-Boolean to indicate that the result is DIRECT or not.
+Boolean to indicate whether the result is DIRECT or not.
 
 =item proxy
 
-URI object for the actual proxy server URL, if Result type is PROXY, otherwise undef.
+URI object for the proxy server URL if the result is PROXY, otherwise undef.
 
 =item socks
 
-URI object for the actual socks server URL, if Result type is SOCKSn, otherwise undef.
+URI object for the socks server URL if the result is SOCKS, otherwise undef.
 
 =back
 
